@@ -61,7 +61,7 @@ CONFIG_FILE = '~/.bbrf/config.json'
 REGEX_DOMAIN = re.compile('^(?:[a-z0-9_](?:[a-z0-9-_]{0,61}[a-z0-9])?\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]$')
 # regex to match IP addresses and CIDR ranges - thanks https://www.regextester.com/93987
 REGEX_IP = re.compile('^([0-9]{1,3}\.){3}[0-9]{1,3}(\/([0-9]|[1-2][0-9]|3[0-2]))?$')
-VERSION = '1.1.2'
+VERSION = '1.1.3'
 
 class BBRFClient:
     config = {}
@@ -309,8 +309,8 @@ class BBRFClient:
         if len(add_domains) > 0:
             success, _ = self.api.add_documents('domain', add_domains, self.get_program(), source=self.arguments['-s'], tags=self.arguments['-t'])
         
-        if self.arguments['--show-new']:
-            return ["[NEW] "+x for x in success if x]
+            if self.arguments['--show-new'] and success:
+                return ["[NEW] "+x for x in success if x]
     
     '''
     This is now balanced over 100 concurrent threads in order to drastically
@@ -321,9 +321,8 @@ class BBRFClient:
         remove = {domain: {'_deleted': True} for domain in domains}
         removed = self.api.update_documents('domain', remove)
         
-        if self.arguments['--show-new']:
-            if removed:
-                return ["[DELETED] "+x for x in removed if x]
+        if self.arguments['--show-new'] and removed:
+            return ["[DELETED] "+x for x in removed if x]
 
     '''
     Update properties of a domain
@@ -361,7 +360,7 @@ class BBRFClient:
         
         updated = self.api.update_documents('domain', {domain: update_domains[domain] for domain in update_domains.keys()}, append_tags=self.arguments['--append-tags'])
         
-        if self.arguments['--show-new']:
+        if self.arguments['--show-new'] and updated:
             return [ "[UPDATED] "+x for x in updated if x]
     
     def add_ips(self, ips):
@@ -399,7 +398,7 @@ class BBRFClient:
 
         success, _ = self.api.add_documents('ip', add_ips, self.get_program(), source=self.arguments['-s'], tags=self.arguments['-t'])
         
-        if self.arguments['--show-new']:
+        if self.arguments['--show-new'] and success:
             return ["[NEW] "+x for x in success if x]
         
     def remove_ips(self, ips):
@@ -407,7 +406,7 @@ class BBRFClient:
         remove = {ip: {'_deleted': True} for ip in ips}
         removed = self.api.update_documents('ip', remove)
         
-        if self.arguments['--show-new']:
+        if self.arguments['--show-new'] and removed:
             return ["[DELETED] "+x for x in removed if x] 
             
     '''
@@ -444,7 +443,7 @@ class BBRFClient:
             
         updated = self.api.update_documents('ip', {ip: update_ips[ip] for ip in update_ips.keys()}, append_tags=self.arguments['--append-tags'])
         
-        if self.arguments['--show-new']:
+        if self.arguments['--show-new'] and updated:
             return [ "[UPDATED] "+x for x in updated if x]
     
     '''
@@ -571,9 +570,13 @@ class BBRFClient:
         updated = self.api.update_documents('url', {url: add_urls[url] for url in failed}, append_tags=self.arguments['--append-tags'])
         
         
-            
-        if self.arguments['--show-new']:
-            return [ "[UPDATED] "+x for x in updated if x] + ["[NEW] "+x for x in success if x]
+        results = []
+        if self.arguments['--show-new'] and updated:
+            results = [ "[UPDATED] "+x for x in updated if x]
+        if self.arguments['--show-new'] and success:
+            results = results + ["[NEW] "+x for x in success if x]
+        if len(results) > 0:
+            return results
         
     '''
     Remove URLs
@@ -648,8 +651,13 @@ class BBRFClient:
                 
         updated = self.api.update_documents('service', {sid: add_services[sid] for sid in failed}, append_tags=self.arguments['--append-tags'])
         
-        if self.arguments['--show-new']:
-            return [ "[UPDATED] "+x for x in updated if x] + ["[NEW] "+x for x in success if x]
+        results = []
+        if self.arguments['--show-new'] and updated:
+            results = [ "[UPDATED] "+x for x in updated if x]
+        if self.arguments['--show-new'] and success:
+            results = results + ["[NEW] "+x for x in success if x]
+        if len(results) > 0:
+            return results
         
     
     def disable_program(self, program):
@@ -860,9 +868,9 @@ class BBRFClient:
                     return self.add_domains(sys.stdin.read().split('\n'))
             if self.arguments['remove']:
                 if self.arguments['<domain>']:
-                    self.remove_domains(self.arguments['<domain>'])
+                    return self.remove_domains(self.arguments['<domain>'])
                 elif self.arguments['-']:
-                    self.remove_domains(sys.stdin.read().split('\n'))
+                    return self.remove_domains(sys.stdin.read().split('\n'))
             if self.arguments['update']:
                 if self.arguments['<domain>']:
                     return self.update_domains(self.arguments['<domain>'])
